@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: A Perl Mail Authentication Milter
-our $VERSION = '3.20240618'; # VERSION
+our $VERSION = '3.20240827'; # VERSION
 use Mail::Milter::Authentication::Handler;
 use Mail::Milter::Authentication::Metric;
 use Mail::Milter::Authentication::Protocol::Milter;
@@ -32,11 +32,14 @@ use vars qw(@ISA);
         my $MYARGS = {
             'ident' => $Mail::Milter::Authentication::Config::IDENT,
             'to_stderr' => 0, # handled elsewhere
+            'to_stdout' => 0, # handled elsewhere
             'log_pid' => 1,
             'facility' => LOG_MAIL,
         };
         if ( exists $config->{ 'log_dispatchouli' } ) {
-            $MYARGS = $config->{ 'log_dispatchouli' };
+            foreach my $k (keys %{$config->{ 'log_dispatchouli' }}) {
+                $MYARGS->{$k} = $config->{ 'log_dispatchouli' }->{$k};
+            }
         }
 
         $LOGGER = Log::Dispatchouli->new( $MYARGS );
@@ -1167,7 +1170,7 @@ Mail::Milter::Authentication - A Perl Mail Authentication Milter
 
 =head1 VERSION
 
-version 3.20240618
+version 3.20240827
 
 =head1 SYNOPSIS
 
