@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: Handler superclass
-our $VERSION = '3.20240618'; # VERSION
+our $VERSION = '3.20240827'; # VERSION
 use Mail::Milter::Authentication::Exception;
 use Mail::Milter::Authentication::Resolver;
 use Date::Format qw{ time2str };
@@ -1234,6 +1234,7 @@ sub get_object {
                 $args{udp_timeout} = $config->{'dns_timeout'}   || 8;
                 $args{tcp_timeout} = $config->{'dns_timeout'}   || 8;
                 $args{retry}       = $config->{'dns_retry'}     || 2;
+                $args{cache_dns_timeouts} = $config->{'cache_dns_timeouts'} // 1;
                 $args{nameservers} = $config->{'dns_resolvers'} if $config->{'dns_resolvers'} && $config->{'dns_resolvers'}->@*;
                 $object = Mail::Milter::Authentication::Resolver->new(%args);
                 $object->udppacketsize(1240);
@@ -1660,6 +1661,7 @@ sub get_domains_from {
         }
         next if ! defined $domain;
         $domain =~ s/\s//g;
+        next if $domain =~ /\@/;
         push @$domains, lc $domain;
     }
     return $domains;
@@ -1822,11 +1824,16 @@ sub get_addresses_from {
         $Address =~ s/\s+\@/\@/;
         $Address =~ s/\@\s+/\@/;
 
+        # Don't allow a multiple @ as this is clearly bogus
+        next if $Address =~ /\@.*\@/;
+
         push @TidyAddresses, $Address;
     }
 
     if ( ! @TidyAddresses ) {
         # We really couldn't parse, so just run with it and hope for the best
+        # But don't return any address with more than one @ as these are clearly bogus
+        return [] if $Str =~ /\@.*\@/;
         push @TidyAddresses, $Str;
     }
 
@@ -2262,7 +2269,7 @@ Mail::Milter::Authentication::Handler - Handler superclass
 
 =head1 VERSION
 
-version 3.20240618
+version 3.20240827
 
 =head1 DESCRIPTION
 
