@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Mail::Milter::Authentication::Pragmas;
 # ABSTRACT: DNS Recolver methods
-our $VERSION = '3.20240618'; # VERSION
+our $VERSION = '3.20240827'; # VERSION
 use base 'Net::DNS::Resolver';
 use Scalar::Util qw{ weaken };
 use Time::HiRes qw{ ualarm gettimeofday };
@@ -18,6 +18,7 @@ use Time::HiRes qw{ ualarm gettimeofday };
         weaken($args{_handler});
         $self->{ _handler } = $args{_handler};
         $self->{ _timedout } = {};
+        $self->{cache_dns_timeouts} = $args{cache_dns_timeouts} // 1;
         return $self;
     }
 }
@@ -76,8 +77,10 @@ sub _do { ## no critic
             if ( $handler->get_time_remaining() > 0 ) {
                 # We have time left, but the lookup timed out
                 # Log this and move on!
-                $handler->log_error( "DNS Lookup $query $domain error, hold set on $org_domain : Timeout calling Net::DNS::Resolver" );
-                $self->{ _timedout }->{ $org_domain } = 1;
+                if ($self->{cache_dns_timeouts}) {
+                    $handler->log_error( "DNS Lookup $query $domain error, hold set on $org_domain : Timeout calling Net::DNS::Resolver" );
+                    $self->{ _timedout }->{ $org_domain } = 1;
+                }
                 $self->errorstring('query timed out');
                 return;
             }
@@ -90,7 +93,7 @@ sub _do { ## no critic
 
     # Timeouts or SERVFAIL are unlikely to recover within the lifetime of this transaction,
     # when we encounter them, don't lookup this org domain again.
-    if ( ( $self->errorstring =~ /timeout/i ) || ( $self->errorstring eq 'query timed out' ) || ( $self->errorstring eq 'SERVFAIL' && $time_taken > $servfail_timeout ) ) {
+    if ( $self->{cache_dns_timeouts} && (( $self->errorstring =~ /timeout/i ) || ( $self->errorstring eq 'query timed out' ) || ( $self->errorstring eq 'SERVFAIL' && $time_taken > $servfail_timeout )) ) {
         $self->{ _timedout }->{ $org_domain } = 1;
         $handler->log_error( "DNS Lookup $query $domain error, hold set on $org_domain : ".$self->errorstring );
       }
@@ -127,7 +130,7 @@ Mail::Milter::Authentication::Resolver - DNS Recolver methods
 
 =head1 VERSION
 
-version 3.20240618
+version 3.20240827
 
 =head1 DESCRIPTION
 
